@@ -1,12 +1,15 @@
 framework.summary <-
 function(group, x, file = NULL)
 {
-     # Function to generate files of framework summary statistics to be saved
-     # in the R working directory.  The file name prefix should identify the 
-     # data source and framework group, e.g., "Project3", the group name and 
-     # variable name are appended together with ".csv" prior to opening a 
-     # file for the results; these can be opened/viewed with MS Excel. 
-     # Function framework.stats is used to compute the summary statistics. 
+     # Function to generate files of framework summary statistics to be saved,
+     # by default in the R working directory.  If provided "file" should name 
+     # the folder where the results are to be saved.  The function appends the 
+     # data frame, framework grouping and variable names together with ".csv" 
+     # prior to opening a file for the results; these can be opened/viewed 
+     # with MS Excel.  To function correctly the data frame containing the
+     # data must be attached prior to running this function, if it has not
+     # already been done so, i.e. attach(dfname), and at close it should be
+     # detached if necesary, detach(dfname).
      #
      # NOTE: Prior to using this function the data frame/matrix containing the
      # variable, 'x', data must be run through ltdl.fix.df to convert any <dl
@@ -14,30 +17,30 @@ function(group, x, file = NULL)
      # required, to convert any zero values or other numeric codes representing 
      # blanks to NAs.
      #
-     # To function correctly the data frame containing the data should be
-     # attached prior to running this function, and detached following, i.e. 
-     # attach(dfname) and at close, if necesary, detach(dfname).
+     # Function framework.stats and summary.stats are used to compute the 
+     # summary statistics. 
      #
+     dfname <- search()[[2]]
      groupname <- deparse(substitute(group))
      xname <- deparse(substitute(x))
+     filename <- paste(dfname, "_", groupname, "_", xname, ".csv", sep = "")
      if (is.null(file)) {
-         wdname <- getwd()
-         dfname <- search()[[2]]
+         file <- getwd()
          cat("  By default the output file will be saved in the R working directory as:\n",
              "  \"dataframename_groupname_xname.csv\"\n",
              " To specify an alternate location and file name prefix, to which:\n",
-             "  \"_groupname_xname.csv\" will be appended, set, for example:\n",
-             "  file = \"D://R_work//Project3//C_soils\"\n",
-             "  If no directory is specified, the file will be saved in the R working directory\n\n")
-         filename <- paste(wdname, "/" ,dfname, "_", groupname, "_", xname, ".csv", sep = "")
+             "  \"/dataframename_groupname_xname.csv\" will be appended, set, for example:\n",
+             "  file = \"D://R_work//Project3\"\n")
      }
-     else filename <- paste(file, "_", groupname, "_", xname, ".csv", sep = "")  
+     filename <- paste(file, "/", filename, sep = "")  
      #
-     cat("  Variable", xname, "subset by", groupname, "- output will be in:\n  ", filename, "\n")
+     cat("\n  Summary statistics for variable", xname, "subset by", groupname, "- output will be in:\n  ", 
+         filename, "\n\n")
      sink(filename)
+     on.exit(sink())
+     #
      cat("Variable,Group,N,NA,Min,2%ile,5%ile,10%ile,25%ile,Median,75%ile,90%ile,95%ile,98%ile,Max,LCI,UCI,MAD,IQSD,Mean,SD,CV%"
          )
-     on.exit(sink())
      #
      framework.stats <- tapply(x, group, framework.stats)
      nstats <- length(framework.stats)
